@@ -1,5 +1,6 @@
 from .QtImportImages import ImportImages
 from .QtImportLabels import ImportLabels
+from .QtImportTagLabLabels import ImportTagLabLabels
 from .QtImportAnnotations import ImportAnnotations
 from .QtImportCoralNetAnnotations import ImportCoralNetAnnotations
 from .QtImportViscoreAnnotations import ImportViscoreAnnotations
@@ -13,6 +14,7 @@ from .QtExportTagLabAnnotations import ExportTagLabAnnotations
 __all__ = [
     'ImportImages',
     'ImportLabels',
+    'ImportTagLabLabels',
     'ImportAnnotations', 
     'ImportCoralNetAnnotations',
     'ImportViscoreAnnotations',
