@@ -12,13 +12,14 @@ from PyQt5.QtWidgets import (QApplication, QMessageBox, QLabel, QGroupBox, QForm
                              QSlider)
 
 from torch.cuda import empty_cache
-from ultralytics import YOLO
+from ultralytics import YOLO, RTDETR
 
 from coralnet_toolbox.MachineLearning.DeployModel.QtBase import Base
 
 from coralnet_toolbox.ResultsProcessor import ResultsProcessor
 
 from coralnet_toolbox.utilities import pixmap_to_numpy
+from coralnet_toolbox.utilities import check_model_architecture
 
 
 # ----------------------------------------------------------------------------------------------------------------------
@@ -28,9 +29,11 @@ from coralnet_toolbox.utilities import pixmap_to_numpy
 
 class Classify(Base):
     def __init__(self, main_window, parent=None):
-        super().__init__(main_window, parent)        
+        super().__init__(main_window, parent)
         self.setWindowTitle("Deploy Classification Model")
-        
+
+        self.task = 'classify'
+
     def showEvent(self, event):
         """
         Handle the show event to update label options and sync uncertainty threshold.
@@ -40,7 +43,7 @@ class Classify(Base):
         """
         super().showEvent(event)
         self.initialize_uncertainty_threshold()
-             
+
     def setup_parameters_layout(self):
         """
         Setup parameter control section in a group box.
@@ -59,10 +62,10 @@ class Classify(Base):
         self.uncertainty_threshold_label = QLabel(f"{self.uncertainty_thresh:.2f}")
         layout.addRow("Uncertainty Threshold", self.uncertainty_threshold_slider)
         layout.addRow("", self.uncertainty_threshold_label)
-        
+
         group_box.setLayout(layout)
         self.layout.addWidget(group_box)
-        
+
     def load_model(self):
         """
         Load the classification model.
@@ -70,19 +73,38 @@ class Classify(Base):
         if not self.model_path:
             QMessageBox.warning(self, "Warning", "Please select a model file first")
             return
-            
+
         try:
             QApplication.setOverrideCursor(Qt.WaitCursor)
-            self.loaded_model = YOLO(self.model_path, task='classify')
-            self.loaded_model(np.zeros((224, 224, 3), dtype=np.uint8))
+
+            # Get the model architecture and task
+            model_architecture, task = check_model_architecture(self.model_path)
+
+            # Check if the model is supported
+            if model_architecture == "yolo":
+                self.loaded_model = YOLO(self.model_path)
+            elif model_architecture == "rtdetr":
+                self.loaded_model = RTDETR(self.model_path)
+            else:
+                QMessageBox.critical(self, "Error", "Model not currently supported.")
+                return
+
+            try:
+                imgsz = self.loaded_model.__dict__['overrides']['imgsz']
+            except:
+                imgsz = 640
+
+            self.loaded_model(np.zeros((imgsz, imgsz, 3), dtype=np.uint8))
             self.class_names = list(self.loaded_model.names.values())
 
             if not self.class_mapping:
                 self.handle_missing_class_mapping()
             else:
                 self.add_labels_to_label_window()
-                self.check_and_display_class_names()
-            
+
+            # Display the class names
+            self.check_and_display_class_names()
+
             # Update the status bar
             self.status_bar.setText(f"Model loaded: {os.path.basename(self.model_path)}")
             QMessageBox.information(self, "Model Loaded", "Model loaded successfully.")
@@ -91,7 +113,7 @@ class Classify(Base):
             QMessageBox.critical(self, "Error", f"Failed to load model: {str(e)}")
         finally:
             QApplication.restoreOverrideCursor()
-            
+
     def predict(self, inputs=None):
         """
         Predict the classification results for the given inputs.
@@ -132,4 +154,4 @@ class Classify(Base):
         # Make cursor normal
         QApplication.restoreOverrideCursor()
         gc.collect()
-        empty_cache()
\ No newline at end of file
+        empty_cache()
