@@ -9,15 +9,18 @@ import numpy as np
 
 from qtrangeslider import QRangeSlider
 from PyQt5.QtCore import Qt
-from PyQt5.QtWidgets import (QApplication, QMessageBox, QLabel, QGroupBox, QFormLayout, QComboBox, QSlider)
+from PyQt5.QtWidgets import (QApplication, QMessageBox, QLabel, QGroupBox, QFormLayout,
+                             QComboBox, QSlider)
 
 from torch.cuda import empty_cache
-from ultralytics import YOLO
+from ultralytics import YOLO, RTDETR
 
 from coralnet_toolbox.MachineLearning.DeployModel.QtBase import Base
 
 from coralnet_toolbox.ResultsProcessor import ResultsProcessor
 
+from coralnet_toolbox.utilities import check_model_architecture
+
 
 # ----------------------------------------------------------------------------------------------------------------------
 # Classes
@@ -28,7 +31,9 @@ class Segment(Base):
     def __init__(self, main_window, parent=None):
         super().__init__(main_window, parent)
         self.setWindowTitle("Deploy Segmentation Model")
-             
+
+        self.task = 'segment'
+
     def showEvent(self, event):
         """
         Handle the show event to update label options and sync uncertainty threshold.
@@ -40,7 +45,7 @@ class Segment(Base):
         self.initialize_uncertainty_threshold()
         self.initialize_iou_threshold()
         self.initialize_area_threshold()
-             
+
     def setup_parameters_layout(self):
         """
         Setup parameter control section in a group box.
@@ -59,7 +64,7 @@ class Segment(Base):
         self.uncertainty_threshold_label = QLabel(f"{self.uncertainty_thresh:.2f}")
         layout.addRow("Uncertainty Threshold", self.uncertainty_threshold_slider)
         layout.addRow("", self.uncertainty_threshold_label)
-        
+
         # IoU threshold controls
         self.iou_thresh = self.main_window.get_iou_thresh()
         self.iou_threshold_slider = QSlider(Qt.Horizontal)
@@ -71,7 +76,7 @@ class Segment(Base):
         self.iou_threshold_label = QLabel(f"{self.iou_thresh:.2f}")
         layout.addRow("IoU Threshold", self.iou_threshold_slider)
         layout.addRow("", self.iou_threshold_label)
-        
+
         # Area threshold controls
         min_val, max_val = self.main_window.get_area_thresh()
         self.area_thresh_min = int(min_val * 100)
@@ -85,16 +90,16 @@ class Segment(Base):
         self.area_threshold_label = QLabel(f"{self.area_thresh_min:.2f} - {self.area_thresh_max:.2f}")
         layout.addRow("Area Threshold", self.area_threshold_slider)
         layout.addRow("", self.area_threshold_label)
-        
+
         # SAM dropdown
         self.use_sam_dropdown = QComboBox()
         self.use_sam_dropdown.addItems(["False", "True"])
         self.use_sam_dropdown.currentIndexChanged.connect(self.is_sam_model_deployed)
         layout.addRow("Use SAM for creating Polygons:", self.use_sam_dropdown)
-        
+
         group_box.setLayout(layout)
         self.layout.addWidget(group_box)
-        
+
     def load_model(self):
         """
         Load the segmentation model.
@@ -102,19 +107,38 @@ class Segment(Base):
         if not self.model_path:
             QMessageBox.warning(self, "Warning", "Please select a model file first")
             return
-            
+
         try:
             QApplication.setOverrideCursor(Qt.WaitCursor)
-            self.loaded_model = YOLO(self.model_path, task='segment')
-            self.loaded_model(np.zeros((640, 640, 3), dtype=np.uint8))
+
+            # Get the model architecture and task
+            model_architecture, task = check_model_architecture(self.model_path)
+
+            # Check if the model is supported
+            if model_architecture == "yolo":
+                self.loaded_model = YOLO(self.model_path)
+            elif model_architecture == "rtdetr":
+                self.loaded_model = RTDETR(self.model_path)
+            else:
+                QMessageBox.critical(self, "Error", "Model not currently supported.")
+                return
+
+            try:
+                imgsz = self.loaded_model.__dict__['overrides']['imgsz']
+            except:
+                imgsz = 640
+
+            self.loaded_model(np.zeros((imgsz, imgsz, 3), dtype=np.uint8))
             self.class_names = list(self.loaded_model.names.values())
 
             if not self.class_mapping:
                 self.handle_missing_class_mapping()
             else:
                 self.add_labels_to_label_window()
-                self.check_and_display_class_names()
-            
+
+            # Display the class names
+            self.check_and_display_class_names()
+
             # Update the status bar
             self.status_bar.setText(f"Model loaded: {os.path.basename(self.model_path)}")
             QMessageBox.information(self, "Model Loaded", "Model loaded successfully.")
@@ -123,7 +147,7 @@ class Segment(Base):
             QMessageBox.critical(self, "Error", f"Failed to load model: {str(e)}")
         finally:
             QApplication.restoreOverrideCursor()
-            
+
     def predict(self, inputs=None):
         """
         Predict the segmentation results for the given inputs.
@@ -153,7 +177,7 @@ class Segment(Base):
                                              iou_thresh=self.main_window.get_iou_thresh(),
                                              min_area_thresh=self.main_window.get_area_thresh_min(),
                                              max_area_thresh=self.main_window.get_area_thresh_max())
-        
+
         # Check if SAM model is deployed
         if self.use_sam_dropdown.currentText() == "True":
             # Apply SAM to the segmentation results
@@ -164,4 +188,4 @@ class Segment(Base):
 
         QApplication.restoreOverrideCursor()
         gc.collect()
-        empty_cache()
\ No newline at end of file
+        empty_cache()
