@@ -91,7 +91,7 @@ class Classify(Base):
         if not image_paths:
             return
 
-        progress_bar = ProgressBar(self, title=f"Creating {split} Dataset")
+        progress_bar = ProgressBar(self.annotation_window, title=f"Creating {split} Dataset")
         progress_bar.show()
         progress_bar.start_progress(len(image_paths))
 
@@ -128,4 +128,4 @@ class Classify(Base):
                 progress_bar.update_progress()
 
         progress_bar.stop_progress()
-        progress_bar.close()
\ No newline at end of file
+        progress_bar.close()
