@@ -13,16 +13,25 @@ from PyQt5.QtWidgets import (QMainWindow, QApplication, QToolBar, QAction, QSize
                              QSpinBox, QSlider, QDialog, QPushButton, QToolButton,
                              QGroupBox)
 
+from coralnet_toolbox.QtEventFilter import GlobalEventFilter
 from coralnet_toolbox.QtAnnotationWindow import AnnotationWindow
 from coralnet_toolbox.QtConfidenceWindow import ConfidenceWindow
 from coralnet_toolbox.QtImageWindow import ImageWindow
 from coralnet_toolbox.QtLabelWindow import LabelWindow
+
 from coralnet_toolbox.QtPatchSampling import PatchSamplingDialog
-from coralnet_toolbox.QtEventFilter import GlobalEventFilter
+
+from coralnet_toolbox.Tile import (
+    TileDetectDataset as DetectTileDatasetDialog,
+    TileSegmentDataset as SegmentTileDatasetDialog,
+    TileDetectInference as DetectTileInferenceDialog,
+    TileSegmentInference as SegmentTileInferenceDialog
+)
 
 from coralnet_toolbox.IO import (
     ImportImages,
     ImportLabels,
+    ImportTagLabLabels,
     ImportAnnotations,
     ImportCoralNetAnnotations,
     ImportViscoreAnnotations,
@@ -31,7 +40,7 @@ from coralnet_toolbox.IO import (
     ExportAnnotations,
     ExportCoralNetAnnotations,
     ExportViscoreAnnotations,
-    ExportTagLabAnnotations
+    ExportTagLabAnnotations,
 )
 
 from coralnet_toolbox.MachineLearning import (
@@ -52,8 +61,6 @@ from coralnet_toolbox.MachineLearning import (
     EvalClassify as ClassifyEvaluateModelDialog,
     EvalDetect as DetectEvaluateModelDialog,
     EvalSegment as SegmentEvaluateModelDialog,
-    TileDetect as DetectTileDatasetDialog,
-    TileSegment as SegmentTileDatasetDialog,
     MergeClassify as ClassifyMergeDatasetsDialog,
     Optimize as OptimizeModelDialog
 )
@@ -95,7 +102,7 @@ class MainWindow(QMainWindow):
         self.rectangle_icon = get_icon("rectangle.png")
         self.polygon_icon = get_icon("polygon.png")
         self.sam_icon = get_icon("sam.png")
-        self.slicer_icon = get_icon("slicer.png")
+        self.tile_icon = get_icon("tile.png")
         self.turtle_icon = get_icon("turtle.png")
         self.rabbit_icon = get_icon("rabbit.png")
         self.rocket_icon = get_icon("rocket.png")
@@ -136,6 +143,7 @@ class MainWindow(QMainWindow):
         # Create dialogs (I/O)
         self.import_images = ImportImages(self)
         self.import_labels = ImportLabels(self)
+        self.import_taglab_labels = ImportTagLabLabels(self)
         self.import_annotations = ImportAnnotations(self)
         self.import_coralnet_annotations = ImportCoralNetAnnotations(self)
         self.import_viscore_annotations = ImportViscoreAnnotations(self)
@@ -146,8 +154,10 @@ class MainWindow(QMainWindow):
         self.export_viscore_annotations = ExportViscoreAnnotations(self)
         self.export_taglab_annotations = ExportTagLabAnnotations(self)
 
-        # Create dialogs (Machine Learning)
+        # Create dialogs (Sample)
         self.patch_annotation_sampling_dialog = PatchSamplingDialog(self)
+                
+        # Create dialogs (Machine Learning)
         self.detect_import_dataset_dialog = DetectImportDatasetDialog(self)
         self.segment_import_dataset_dialog = SegmentImportDatasetDialog(self)
         self.classify_export_dataset_dialog = ClassifyExportDatasetDialog(self)
@@ -160,8 +170,6 @@ class MainWindow(QMainWindow):
         self.classify_evaluate_model_dialog = ClassifyEvaluateModelDialog(self)
         self.detect_evaluate_model_dialog = DetectEvaluateModelDialog(self)
         self.segment_evaluate_model_dialog = SegmentEvaluateModelDialog(self)
-        self.detect_tile_dataset_dialog = DetectTileDatasetDialog(self)
-        self.segment_tile_dataset_dialog = SegmentTileDatasetDialog(self)
         self.optimize_model_dialog = OptimizeModelDialog(self)
         self.classify_deploy_model_dialog = ClassifyDeployModelDialog(self)
         self.detect_deploy_model_dialog = DetectDeployModelDialog(self)
@@ -169,11 +177,21 @@ class MainWindow(QMainWindow):
         self.classify_batch_inference_dialog = ClassifyBatchInferenceDialog(self)
         self.detect_batch_inference_dialog = DetectBatchInferenceDialog(self)
         self.segment_batch_inference_dialog = SegmentBatchInferenceDialog(self)
+        
+        # Create dialogs (SAM)
         self.sam_deploy_model_dialog = SAMDeployPredictorDialog(self)
         self.sam_deploy_generator_dialog = SAMDeployGeneratorDialog(self)
         self.sam_batch_inference_dialog = SAMBatchInferenceDialog(self)
+        
+        # Create dialogs (AutoDistill)
         self.auto_distill_deploy_model_dialog = AutoDistillDeployModelDialog(self)
         self.auto_distill_batch_inference_dialog = AutoDistillBatchInferenceDialog(self)
+        
+        # Create dialogs (Tile)
+        self.detect_tile_dataset_dialog = DetectTileDatasetDialog(self)
+        self.segment_tile_dataset_dialog = SegmentTileDatasetDialog(self)
+        self.detect_tile_inference_dialog = DetectTileInferenceDialog(self)
+        self.segment_tile_inference_dialog = SegmentTileInferenceDialog(self)
 
         # Connect signals to update status bar
         self.annotation_window.imageLoaded.connect(self.update_image_dimensions)
@@ -230,6 +248,11 @@ class MainWindow(QMainWindow):
         self.import_labels_action.triggered.connect(self.import_labels.import_labels)
         self.import_labels_menu.addAction(self.import_labels_action)
 
+        # Import TagLab Labels
+        self.import_taglab_labels_action = QAction("TagLab Labels (JSON)", self)
+        self.import_taglab_labels_action.triggered.connect(self.import_taglab_labels.import_taglab_labels)
+        self.import_labels_menu.addAction(self.import_taglab_labels_action)
+
         # Annotations submenu
         self.import_annotations_menu = self.import_menu.addMenu("Annotations")
 
@@ -322,6 +345,35 @@ class MainWindow(QMainWindow):
         self.annotation_sampling_action = QAction("Sample", self)
         self.annotation_sampling_action.triggered.connect(self.open_patch_annotation_sampling_dialog)
         self.menu_bar.addAction(self.annotation_sampling_action)
+        
+        # Tile menu
+        self.tile_menu = self.menu_bar.addMenu("Tile")
+
+        # Tile Dataset submenu
+        self.tile_dataset_menu = self.tile_menu.addMenu("Tile Dataset")
+        
+        # Tile Detect Dataset
+        self.detect_tile_dataset_action = QAction("Detect", self)
+        self.detect_tile_dataset_action.triggered.connect(self.open_detect_tile_dataset_dialog)
+        self.tile_dataset_menu.addAction(self.detect_tile_dataset_action)
+
+        # Tile Segment Dataset
+        self.segment_tile_dataset_action = QAction("Segment", self)
+        self.segment_tile_dataset_action.triggered.connect(self.open_segment_tile_dataset_dialog)
+        self.tile_dataset_menu.addAction(self.segment_tile_dataset_action)
+        
+        # Tile Inference submenu
+        # self.tile_inference_menu = self.tile_menu.addMenu("Tile Inference")
+        
+        # Tile Detect Inference
+        # self.detect_tile_inference_action = QAction("Detect", self)
+        # self.detect_tile_inference_action.triggered.connect(self.open_detect_tile_inference_dialog)
+        # self.tile_inference_menu.addAction(self.detect_tile_inference_action)
+        
+        # Tile Segment Inference
+        # self.segment_tile_inference_action = QAction("Segment", self)
+        # self.segment_tile_inference_action.triggered.connect(self.open_segment_tile_inference_dialog)
+        # self.tile_inference_menu.addAction(self.segment_tile_inference_action)
 
         # CoralNet menu
         # self.coralnet_menu = self.menu_bar.addMenu("CoralNet")
@@ -357,19 +409,6 @@ class MainWindow(QMainWindow):
         self.ml_classify_merge_datasets_action.triggered.connect(self.open_classify_merge_datasets_dialog)
         self.ml_merge_datasets_menu.addAction(self.ml_classify_merge_datasets_action)
 
-        # Tile Dataset submenu
-        self.ml_tile_dataset_menu = self.ml_menu.addMenu("Tile Dataset")
-
-        # Tile Detection Dataset
-        self.ml_detect_tile_dataset_action = QAction("Detect", self)
-        self.ml_detect_tile_dataset_action.triggered.connect(self.open_detect_tile_dataset_dialog)
-        self.ml_tile_dataset_menu.addAction(self.ml_detect_tile_dataset_action)
-
-        # Tile Segment Dataset
-        self.ml_segment_tile_dataset_action = QAction("Segment", self)
-        self.ml_segment_tile_dataset_action.triggered.connect(self.open_segment_tile_dataset_dialog)
-        self.ml_tile_dataset_menu.addAction(self.ml_segment_tile_dataset_action)
-
         # Train Model submenu
         self.ml_train_model_menu = self.ml_menu.addMenu("Train Model")
 
@@ -535,10 +574,10 @@ class MainWindow(QMainWindow):
 
         self.toolbar.addSeparator()
 
-        self.slicer_tool_action = QAction(self.slicer_icon, "Slicer", self)
-        self.slicer_tool_action.setCheckable(False)
-        self.slicer_tool_action.triggered.connect(self.toggle_tool)
-        # self.toolbar.addAction(self.slicer_tool_action)  TODO
+        self.tile_inference_tool_action = QAction(self.tile_icon, "Tile Inference", self)
+        self.tile_inference_tool_action.setCheckable(False)
+        self.tile_inference_tool_action.triggered.connect(self.toggle_tool)
+        # self.toolbar.addAction(self.tile_inference_tool_action)  # TODO
 
         self.toolbar.addSeparator()
 
@@ -738,7 +777,7 @@ class MainWindow(QMainWindow):
 
     def changeEvent(self, event):
         super().changeEvent(event)
-        if event.type() == QEvent.WindowStateChange:
+        if (event.type() == QEvent.WindowStateChange):
             if self.windowState() & Qt.WindowMinimized:
                 # Allow minimizing
                 pass
@@ -1142,6 +1181,50 @@ class MainWindow(QMainWindow):
             self.segment_tile_dataset_dialog.exec_()
         except Exception as e:
             QMessageBox.critical(self, "Critical Error", f"{e}")
+            
+    def open_detect_tile_inference_dialog(self):
+        
+        if not self.image_window.image_paths:
+            # Check if there are any images in the project
+            QMessageBox.warning(self,
+                                "No Images Loaded",
+                                "Please load images into the project before sampling annotations.")
+            return
+        
+        # TODO
+        # if not self.detect_deploy_model_dialog.loaded_model:
+        #     QMessageBox.warning(self,
+        #                         "Tile Inference",
+        #                         "Please deploy a model before running batch inference.")
+        #     return
+        
+        try:
+            self.untoggle_all_tools()
+            self.detect_tile_inference_dialog.exec_()
+        except Exception as e:
+            QMessageBox.critical(self, "Critical Error", f"{e}")
+            
+    def open_segment_tile_inference_dialog(self):
+        
+        if not self.image_window.image_paths:
+            # Check if there are any images in the project
+            QMessageBox.warning(self,
+                                "No Images Loaded",
+                                "Please load images into the project before sampling annotations.")
+            return
+        
+        # TODO
+        # if not self.segment_deploy_model_dialog.loaded_model:
+        #     QMessageBox.warning(self,
+        #                         "Tile Inference",
+        #                         "Please deploy a model before running batch inference.")
+        #     return
+        
+        try:
+            self.untoggle_all_tools()
+            self.segment_tile_inference_dialog.exec_()
+        except Exception as e:
+            QMessageBox.critical(self, "Critical Error", f"{e}")
 
     def open_classify_train_model_dialog(self):
         try:
